==> fetch.php?media=uls%3Auls_update-1.9.5.tgz: update/von_1.9.4/sql/komprimierung_woche.sql <==
set @@character_set_client = 'utf8';

delimiter //

DROP PROCEDURE IF EXISTS komprimierung_woche//
create procedure komprimierung_woche(weekstart integer)
  deterministic
  sql security invoker
begin
  declare nflag bool;
  declare lwid, wid, uid, z integer;
  declare mode varchar(12);
  declare lw varchar(50);
  declare unit, outunit varchar(100);
  declare mw varchar(20000);
  declare mdate, mkd, lastdate date;
  declare ws integer;
  declare selcur cursor for
    select lwerteindizes.ID, werteindizes.ID, groupfunctions.code,
      lkdate, date(lastdatum), unitID, einheiten.name,
      type = 'num' OR groupfunctions.code in ('count','differ','firstsize','lastsize')
    from lwerteindizes
    join werteindizes using(serverID, sectionID, teststepID, teststepdetailsID, accessID)
    join letztewerte on letztewerte.ID = werteindizes.ID
    join teststepdetails on teststepdetails.ID = teststepdetailsID
    join einheiten on einheiten.ID = einheitID
    join groupfunctions on groupfunctions.ID = groupfunctionsID
    left join komprimierungids on komprimierungids.lwerteindizesID = lwerteindizes.ID
    where lastdatum - interval 14 day >= lkdate and period = 'Week'
      and (lwerteindizes.single = '1' OR komprimierungids.lwerteindizesID is not NULL)
    group by lwerteindizes.ID
    order by wtab, werteindizes.ID;
  declare continue handler for not found set z = 1;

  if 1 <= weekstart AND weekstart <= 7 then
    set ws = weekstart;
  else
     set ws = 2;
  end if;

  set z = 0;
  open selcur;
  fetch selcur into lwid, wid, mode, mdate, mkd, uid, unit, nflag;
  while z != 1 do
    if mdate = '0000-00-00' then
      set mdate = (select min(fdate) from wertedates where werteindizesID = wid);
    else
      set mdate = mdate + interval 7 day;
    end if;
    set mdate = mdate - interval dayofweek(mdate)-ws+if(dayofweek(mdate) < ws, 7, 0) day;
    set lastdate = mkd - interval 7 day;
    while mdate <= lastdate do
      if (select count(*) from wertedates
          where werteindizesID = wid and mdate <= ldate
            and fdate < mdate + interval 7 day) > 0 then
        if nflag then
          if unit = '[E]' AND mode not in ('count','differ','firstsize','lastsize') then
            if uid is NULL then
              select lu.unitID
                from lwerteindizes as lr
                join lwerteindizes as lu using (serverID, sectionID, teststepID, teststepdetailsID, accessID)
                where lr.ID = lwid and lu.unitID is not NULL limit 1 into uid;
              if uid is NULL then
                select e.ID
                  from einheiten as e, twerte as w
                  where w.werteindizesID = wid
                    and substr(w.wert, instr(w.wert, ' ')+1) = e.name
                  group by e.ID order by count(*) desc, e.sifaktor desc limit 1 into uid;
              end if;
              if uid is not NULL then
                update lwerteindizes set unitID = uid where ID = lwid;
              end if;
            end if;
            if uid is not NULL then
              select name from einheiten where ID = uid into outunit;
              if mode like 'last-first%' OR mode = 'grad' then
                set mw = getewertvbextfilter(wid,
                  getlastwdate(wid, mdate - interval 7 day, mdate),
                  mdate + interval 7 day - interval 1 second, mode, '00:00:00',
                  '23:59:59', '', '', '', '', '', '',  '', '', '', '', '', '', outunit);
              else
                set mw = getewertvbextfilter(wid, mdate,
                  mdate + interval 7 day - interval 1 second, mode, '00:00:00',
                  '23:59:59', '', '', '', '', '', '',  '', '', '', '', '', '', outunit);
              end if;
              if coalesce(mw, '') != '' then
                insert into mwerte (lwerteindizesID, wert, datum) values
                  (lwid, mw, mdate + interval '3 12' day_hour);
                call lwdates(lwid, mdate + interval 3 day);
              end if;
            end if;
          else
            if mode like 'last-first%' OR mode = 'grad' then
              set lw = getwertvb(wid, getlastwdate(wid, mdate - interval 7 day, mdate),
                                 mdate + interval 7 day - interval 1 second, mode);
            else
              set lw = getwertvb(wid, mdate, mdate + interval 7 day - interval 1 second,
                                 mode);
            end if;
            if coalesce(lw, '') != '' then
              insert into lwerte (lwerteindizesID, wert, datum) values
                (lwid, lw, mdate + interval '3 12' day_hour);
              call lwdates(lwid, mdate + interval 3 day);
            end if;
          end if;
        else
          if mode like 'last-first%' OR mode = 'grad' then
            set mw = getwertvb(wid, getlastwdate(wid, mdate - interval 7 day, mdate),
                               mdate + interval 7 day - interval 1 second, mode);
          else
            set mw = getwertvb(wid, mdate, mdate + interval 7 day - interval 1 second,
                               mode);
          end if;
          if coalesce(mw, '') != '' then
            insert into mwerte (lwerteindizesID, wert, datum) values
              (lwid, mw, mdate + interval '3 12' day_hour);
            call lwdates(lwid, mdate + interval 3 day);
          end if;
        end if;
      end if;
      update lwerteindizes set lkdate = mdate where ID = lwid;
      set mdate = mdate + interval 7 day;
    end while;
    set z = 0;
    fetch selcur into lwid, wid, mode, mdate, mkd, uid, unit, nflag;
  end while;
  close selcur;

end//

GRANT EXECUTE on PROCEDURE komprimierung_woche to loggingadmin@'localhost'//

==> fetch.php?media=uls%3Auls_update-1.9.6.tgz: update/von_1.9.5/sql/komprimierung_woche.sql <==
-- komprimierung_woche.sql
--
-- procedure komprimierung_woche(weekstart)
-- weekstart: number of first day of weeks (1 = sun, 7 = sat)
--
-- calculate and insert compressed values for one week
--
-- komprimiert wird bis zum Vortag der letzten Werte, aber mindestens bis zur vorletzten Woche

set @@character_set_client = 'utf8';

delimiter //

DROP PROCEDURE IF EXISTS komprimierung_woche//
create procedure komprimierung_woche(weekstart integer)
  deterministic
  sql security invoker
begin
  declare nflag bool;
  declare lwid, wid, uid, z integer;
  declare mode varchar(12);
  declare lw varchar(50);
  declare unit, outunit varchar(100);
  declare mw varchar(20000);
  declare mdate, mkd, lastdate date;
  declare ws integer;
  declare selcur cursor for
    select lwerteindizes.ID, werteindizes.ID, groupfunctions.code,
      lkdate, greatest(least(date(lastdatum), curdate()), curdate() - interval 1 week), unitID, einheiten.name,
      type = 'num' OR groupfunctions.code in ('count','differ','firstsize','lastsize')
    from lwerteindizes
    join werteindizes using(serverID, sectionID, teststepID, teststepdetailsID, accessID)
    join letztewerte on letztewerte.ID = werteindizes.ID
    join teststepdetails on teststepdetails.ID = teststepdetailsID
    join einheiten on einheiten.ID = einheitID
    join groupfunctions on groupfunctions.ID = groupfunctionsID
    left join komprimierungids on komprimierungids.lwerteindizesID = lwerteindizes.ID
    where lastdatum - interval 14 day >= lkdate and period = 'Week'
      and (lwerteindizes.single = '1' OR komprimierungids.lwerteindizesID is not NULL)
    group by lwerteindizes.ID
    order by wtab, werteindizes.ID;
  declare continue handler for not found set z = 1;

  if 1 <= weekstart AND weekstart <= 7 then
    set ws = weekstart;
  else
     set ws = 2;
  end if;

  set z = 0;
  open selcur;
  fetch selcur into lwid, wid, mode, mdate, mkd, uid, unit, nflag;
  while z != 1 do
    if mdate = '0000-00-00' then
      set mdate = (select min(fdate) from wertedates where werteindizesID = wid);
    else
      set mdate = mdate + interval 7 day;
    end if;
    set mdate = mdate - interval dayofweek(mdate)-ws+if(dayofweek(mdate) < ws, 7, 0) day;
    set lastdate = mkd - interval 7 day;
    while mdate <= lastdate do
      if (select count(*) from wertedates
          where werteindizesID = wid and mdate <= ldate
            and fdate < mdate + interval 7 day) > 0 then
        if nflag then
          if unit = '[E]' AND mode not in ('count','differ','firstsize','lastsize') then
            if uid is NULL then
              select lu.unitID into uid
                from lwerteindizes as lr
                join lwerteindizes as lu using (serverID, sectionID, teststepID, teststepdetailsID, accessID)
                where lr.ID = lwid and lu.unitID is not NULL limit 1;
              if uid is NULL then
                select e.ID into uid
                  from einheiten as e, twerte as w
                  where w.werteindizesID = wid
                    and substr(w.wert, instr(w.wert, ' ')+1) = e.name
                  group by e.ID order by count(*) desc, e.sifaktor desc limit 1;
              end if;
              if uid is not NULL then
                update lwerteindizes set unitID = uid where ID = lwid;
              end if;
            end if;
            if uid is not NULL then
              select name into outunit from einheiten where ID = uid;
              if mode like 'last-first%' OR mode = 'grad' then
                set mw = getewertvbextfilteru(wid,
                  getlastwdate(wid, mdate - interval 7 day, mdate),
                  mdate + interval 7 day - interval 1 second, mode, '00:00:00',
                  '23:59:59', '', '', '', '', '', '',  '', '', '', '', '', '', outunit);
              else
                set mw = getewertvbextfilteru(wid, mdate,
                  mdate + interval 7 day - interval 1 second, mode, '00:00:00',
                  '23:59:59', '', '', '', '', '', '',  '', '', '', '', '', '', outunit);
              end if;
              if coalesce(mw, '') != '' then
                insert into mwerte (lwerteindizesID, wert, datum) values
                  (lwid, mw, mdate + interval '3 12' day_hour);
                call lwdates(lwid, mdate + interval 3 day);
              end if;
            end if;
          else
            if mode like 'last-first%' OR mode = 'grad' then
              set lw = getwertvb(wid, getlastwdate(wid, mdate - interval 7 day, mdate),
                                 mdate + interval 7 day - interval 1 second, mode);
            else
              set lw = getwertvb(wid, mdate, mdate + interval 7 day - interval 1 second,
                                 mode);
            end if;
            if coalesce(lw, '') != '' then
              insert into lwerte (lwerteindizesID, wert, datum) values
                (lwid, lw, mdate + interval '3 12' day_hour);
              call lwdates(lwid, mdate + interval 3 day);
            end if;
          end if;
        else
          if mode like 'last-first%' OR mode = 'grad' then
            set mw = getwertvb(wid, getlastwdate(wid, mdate - interval 7 day, mdate),
                               mdate + interval 7 day - interval 1 second, mode);
          else
            set mw = getwertvb(wid, mdate, mdate + interval 7 day - interval 1 second,
                               mode);
          end if;
          if coalesce(mw, '') != '' then
            insert into mwerte (lwerteindizesID, wert, datum) values
              (lwid, mw, mdate + interval '3 12' day_hour);
            call lwdates(lwid, mdate + interval 3 day);
          end if;
        end if;
      end if;
      update lwerteindizes set lkdate = mdate where ID = lwid;
      set mdate = mdate + interval 7 day;
    end while;
    set z = 0;
    fetch selcur into lwid, wid, mode, mdate, mkd, uid, unit, nflag;
  end while;
  close selcur;

end//

GRANT EXECUTE on PROCEDURE komprimierung_woche to loggingadmin@'localhost'//
